==> homesitemaker-v0.4.3.tar.gz: homesitemaker/includes/languages/english/homesite-includes-control-panel-help-control-panel.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/includes/control-panel/help/control-panel.php ----------

$TEXT001="The Control Panel is divided into four main sections"; 

$TEXT002="If you have the required privileges you can add new users, ".
         "edit you user profile and remove users. Otherwise, you only can edit your account ".
         "and see the site users list."; 

$TEXT003="Under construction";
 
$TEXT004="This section will be focused in providing a easy way to modify the look and feel of all".
         " the site. Actually, you all these things are controlled from the file site_config.php";
 
$TEXT005="Under construction";

?>

==> homesitemaker-v0.4.7-1.tar.gz: homesitemaker/includes/languages/english/homesite-includes-control-panel-help-control-panel.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/includes/control-panel/help/control-panel.php ----------

$TEXT001="The Control Panel is divided into four main sections"; 

$TEXT002="If you have the required privileges you can add new users, ".
         "edit you user profile and remove users. Otherwise, you only can edit your account ".
         "and see the site users list."; 

$TEXT003="This section will be available soon. It will provide an easy way to modify some.".
         "important settings such as the title and type of all the sections, the language of the site,".
         "or the method you want to use to send or edit news.";
 
$TEXT004="This section will be used to allow easy modifications of the look and feel of the whole web site.";
 
$TEXT005="This section try to explain all the things you can do with the Homesite Maker Control Panel and how to do it.";

?>
